// Load data from CSV file asynchronously
d3.csv(
  'https://raw.githubusercontent.com/rajasekhar2301/sekhar-assignment2/main/data-1.csv',
)
  .then(function (data) {
    // Set the dimensions and margins of the graph
    var margin = {
        top: 10,
        right: 300,
        bottom: 50,
        left: 50,
      },
      width = 960 - margin.left - margin.right,
      height = 500 - margin.top - margin.bottom;

    // Append the svg object to the div called 'chart'
    var svg = d3
      .select('#chart')
      .append('svg')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr(
        'transform',
        `translate(${margin.left},${margin.top})`,
      );

    // Parse the Data
    var genres = data.columns.slice(1).map(function (id) {
      return {
        id: id,
        values: data.map((d) => {
          return { genre: d.genre, rating: +d[id] };
        }),
      };
    });

    // Set the ranges
    var x = d3
      .scaleBand()
      .range([0, width])
      .padding(0.1)
      .domain(
        data.map(function (d) {
          return d.genre;
        }),
      );
    var y = d3
      .scaleLinear()
      .range([height, 0])
      .domain([
        0,
        d3.max(genres, (d) =>
          d3.max(d.values, (c) => c.rating),
        ),
      ]);

    // Define the area generator
    var area = d3
      .area()
      .x(function (d) {
        return x(d.genre) + x.bandwidth() / 2;
      }) // center the area in the band
      .y0(height)
      .y1(function (d) {
        return y(d.rating);
      });

    // Add the area
    svg
      .selectAll('.area')
      .data(genres)
      .enter()
      .append('path')
      .attr('class', 'area')
      .attr('d', function (d) {
        return area(d.values);
      })
      .style('fill', function (d, i) {
        return d3.schemeCategory10[i % 10];
      }); // Use a color scheme

    // Add the X Axis
    var xAxisGroup = svg
      .append('g')
      .attr('transform', `translate(0,${height})`)
      .call(d3.axisBottom(x));

    // Text label for the x-axis
    xAxisGroup
      .append('text')
      .attr('class', 'axis-label')
      .attr('y', 40)
      .attr('x', width / 2)
      .attr('text-anchor', 'middle')
      .text('Genres');

    // Add the Y Axis
    var yAxisGroup = svg.append('g').call(d3.axisLeft(y));

    // Text label for the y-axis
    yAxisGroup
      .append('text')
      .attr('class', 'axis-label')
      .attr('transform', 'rotate(-90)')
      .attr('y', -40)
      .attr('x', -height / 2)
      .attr('text-anchor', 'middle')
      .text('Rating Proportion');

    // Add a legend to the right of the chart
    var legend = svg
      .selectAll('.legend')
      .data(genres)
      .enter()
      .append('g')
      .attr('class', 'legend')
      .attr('transform', function (d, i) {
        return (
          'translate(' +
          (width + margin.right - 250) +
          ',' +
          i * 20 +
          ')'
        );
      });

    legend
      .append('rect')
      .attr('x', 0)
      .attr('width', 18)
      .attr('height', 18)
      .style('fill', function (d, i) {
        return d3.schemeCategory10[i % 10];
      });

    legend
      .append('text')
      .attr('x', 22)
      .attr('y', 9)
      .attr('dy', '.35em')
      .text(function (d) {
        return d.id;
      });
  })
  .catch(function (error) {
    console.log('Error loading the data: ', error);
  });
